Improve this doc View Source

A jQuery or jqLite wrapper for the browser's `window.document` object.

## Dependencies

- `$window`

## Example

Edit in Plunker

    <div ng-controller="ExampleController">
      <p>$document title: <b ng-bind="title"></b></p>
      <p>window.document title: <b ng-bind="windowTitle"></b></p>
    </div>

    angular.module('documentExample', [])
      .controller('ExampleController', ['$scope', '$document', function($scope, $document) {
        $scope.title = $document[0].title;
        $scope.windowTitle = angular.element(window.document)[0].title;
      }]);